==> oarepo-oai-pmh-harvester-4.0.23.tar.gz: oarepo-oai-pmh-harvester-4.0.23/oarepo_oaipmh_harvester/oai_record/ext.py <==
import re

from oarepo_oaipmh_harvester.oai_record import config as config


class OaiRecordExt:
    def __init__(self, app=None):
        """Extension initialization."""
        self.resource = None
        self.service = None

        if app:
            self.init_app(app)

    def init_app(self, app):
        """Flask application initialization."""

        self.init_config(app)
        if not self.is_inherited():
            self.init_resource(app)
            self.register_flask_extension(app)

    def register_flask_extension(self, app):
        app.extensions["oarepo-oaipmh-record"] = self

    def init_resource(self, app):
        """Initialize vocabulary resources."""

        self.service = app.config["OAI_RECORD_RECORD_SERVICE_CLASS"](
            config=app.config["OAI_RECORD_RECORD_SERVICE_CONFIG"](),
        )

        self.resource = app.config["OAI_RECORD_RECORD_RESOURCE_CLASS"](
            service=self.service,
            config=app.config["OAI_RECORD_RECORD_RESOURCE_CONFIG"](),
        )

    def init_config(self, app):
        """Initialize configuration."""
        for identifier in dir(config):
            if re.match("^[A-Z_0-9]*$", identifier) and not identifier.startswith("_"):
                app.config.setdefault(identifier, getattr(config, identifier))

    def is_inherited(self):
        from importlib_metadata import entry_points

        ext_class = type(self)
        for ep in entry_points(group="invenio_base.apps"):
            loaded = ep.load()
            if loaded is not ext_class and issubclass(ext_class, loaded):
                return True
        for ep in entry_points(group="invenio_base.api_apps"):
            loaded = ep.load()
            if loaded is not ext_class and issubclass(ext_class, loaded):
                return True
        return False

==> oarepo-oai-pmh-harvester-4.0.29.tar.gz: oarepo-oai-pmh-harvester-4.0.29/oarepo_oaipmh_harvester/oai_record/ext.py <==
import re
from functools import cached_property

from oarepo_oaipmh_harvester.oai_record import config as config


class Oai_recordExt:
    def __init__(self, app=None):
        if app:
            self.init_app(app)

    def init_app(self, app):
        """Flask application initialization."""

        self.init_config(app)
        if not self.is_inherited():
            self.register_flask_extension(app)

    def register_flask_extension(self, app):
        app.extensions["oarepo_oaipmh_harvester.oai_record"] = self

    def init_config(self, app):
        """Initialize configuration."""
        for identifier in dir(config):
            if re.match("^[A-Z_0-9]*$", identifier) and not identifier.startswith("_"):
                app.config.setdefault(identifier, getattr(config, identifier))

    def is_inherited(self):
        from importlib_metadata import entry_points

        ext_class = type(self)
        for ep in entry_points(group="invenio_base.apps"):
            loaded = ep.load()
            if loaded is not ext_class and issubclass(ext_class, loaded):
                return True
        for ep in entry_points(group="invenio_base.api_apps"):
            loaded = ep.load()
            if loaded is not ext_class and issubclass(ext_class, loaded):
                return True
        return False

    @cached_property
    def service_records(self):
        return config.OAI_RECORD_RECORD_SERVICE_CLASS(
            config=config.OAI_RECORD_RECORD_SERVICE_CONFIG(),
        )

    @cached_property
    def resource_records(self):
        return config.OAI_RECORD_RECORD_RESOURCE_CLASS(
            service=self.service_records,
            config=config.OAI_RECORD_RECORD_RESOURCE_CONFIG(),
        )
